Création de plages d'adresses publiques

Vous pouvez créer une plage d'adresses publique en définissant sa taille et, si vous le souhaitez, en spécifiant un VPC à lui associer dans n'importe quelle zone de disponibilité du compte.BYOIP (IPv4) Beta Les adresses peuvent être attribuées à partir de plages d'adresses IP gérées par l' IBM ou à partir d'un CIDR personnalisé autorisé si vous souhaitez utiliser votre propre plage d'adresses IP routables publiquement.

Si le VPC est supprimé alors qu'il est lié à une plage d'adresses publiques, la plage d'adresses continue d'exister et peut être liée ultérieurement à un autre VPC dans n'importe quelle zone de disponibilité.

Vous pouvez créer des plages d'adresses publiques à l'aide de la console, de l'interface de programmation, de l'API et de Terraform.

Avant de commencer

Assurez-vous de revoir les considérations de planification pour les plages d’adresses publiques.

Création de plages d'adresses publiques dans la console

Pour créer des plages d'adresses publiques dans la console IBM Cloud, procédez comme suit :

  1. Depuis la console IBM Cloud, sélectionnez l' icône Menu du menu Navigation, puis cliquez sur l'icône Infrastructure VPC > Réseau > Plages d'adresses publiques. La page Public Address Ranges for VPC s'affiche.

  2. Cliquez sur Créer pour accéder à la page de mise à disposition.

  3. Dans la section Emplacement, indiquez la région dans laquelle vous souhaitez que la plage d'adresses publiques soit créée.

  4. Dans la section Détails, indiquez les informations suivantes :

    • Taille: sélectionnez la taille (nombre d'adresses IP) de la plage d'adresses. Vous pouvez choisir entre 1, 2, 4, 8 ou 16 adresses IP à inclure dans le bloc.

      Une fois que vous avez créé une plage d'adresses publiques, vous ne pouvez plus en modifier la taille.

    • Nom: (facultatif): saisissez un nom pour la plage d'adresses publiques, par exemple my-public-address-range.

    • Groupe de ressources: Sélectionnez un groupe de ressources pour la plage d'adresses publiques.

      Une fois que vous avez créé une plage d'adresses publiques, vous ne pouvez plus modifier le groupe de ressources.

    • Balises: (facultatif) Ajoutez des balises pour vous aider à organiser et à retrouver vos ressources. Vous pouvez toujours ajouter d'autres balises ultérieurement. Pour plus d'informations, consultez la section Utilisation des balises. BYOIP (IPv4) Beta

    • Source de la diffusion publique: sélectionnez l'une des options suivantes :

      • IBM CIDR: choisissez parmi les plages d'adresses IP gérées par l' IBM. Sélectionnez ensuite la taille (nombre d'adresses IP) de la plage d'adresses. Vous pouvez choisir entre 1, 2, 4, 8 ou 16 adresses IP à inclure dans le bloc.

        Une fois que vous avez créé une plage d'adresses publiques, vous ne pouvez plus en modifier la taille.

      • CIDR personnalisés autorisés: dans la liste des CIDR autorisés, sélectionnez le CIDR personnalisé autorisé à partir duquel vous souhaitez attribuer des adresses. Les blocs CIDR disponibles sont limités aux plages valides et non allouées au sein du CIDR personnalisé et autorisé sélectionné.

        Lorsque vous sélectionnez un CIDR personnalisé autorisé, vous attribuez des adresses issues de votre propre plage IP plutôt que des pools gérés par l' IBM. Si aucun CIDR autorisé n'apparaît dans le menu, vous pouvez saisir des adresses IP issues d'un CIDR autorisé. Le nouveau CIDR est disponible dès maintenant.

        Pour plus d'informations, consultez la section Provisionnement d'un CIDR personnalisé autorisé.

      Pour les CIDR autorisés par zone, seuls les CIDR associés à la zone sélectionnée sont disponibles.

  5. (Facultatif) Si vous souhaitez lier votre plage d'adresses publiques à un VPC existant, activez le commutateur Bind. Sélectionnez ensuite le VPC et la zone de disponibilité auxquels vous souhaitez vous lier.

    Vous pouvez lier une plage d'adresses publiques à n'importe quel VPC dans une zone de disponibilité unique qui existe déjà dans votre compte. Vous pouvez également lier la plage d'adresses à un VPC ultérieurement. Pour plus d'informations, voir Relier une plage d'adresses publiques.

  6. Cliquez sur Créer. L'utilisation de la plage d'adresses publiques est demandée.

Sur la page Plages d'adresses publiques pour VPC, votre plage d'adresses apparaît dans le tableau. Il faut quelques minutes pour que le statut de la plage d’adresses publiques passe de à Updating Stable. Lorsqu'elle est en état Stable, la plage d'adresses est prête à être utilisée.

Création de plages d'adresses publiques à partir de l'interface de ligne de commande

Pour créer des plages d'adresses publiques à partir de la ligne de commande, procédez comme suit :

  1. Configurez votre environnement d'interface de ligne de commande.

  2. Connectez-vous à votre environnement CLI. Une fois que vous avez saisi le mot de passe, le système vous invite à indiquer le compte et la région à utiliser :

    ibmcloud login --sso
    
  3. Exécutez la commande suivante :

    ibmcloud is public-address-range-create --ipv4-address-count IPV4_ADDRESS_COUNT [--name NAME] [--vpc VPC --zone ZONE] [--resource-group-id RESOURCE_GROUP_ID | --resource-group-name RESOURCE_GROUP_NAME] [--output JSON] [-q, --quiet]
    

    BYOIP (IPv4) Beta

    ibmcloud is public-address-range-create (--ipv4-address-count IPV4_ADDRESS_COUNT | --cidr CIDR) [--name NAME] [--vpc VPC --zone ZONE] [--resource-group-id RESOURCE_GROUP_ID | --resource-group-name RESOURCE_GROUP_NAME] [--output JSON] [-q, --quiet]
    

    Où :

    --ipv4-address-count
    Nombre total d'adresses IPv4 publiques requises. Doit être une puissance de 2.BYOIP (IPv4) Beta S'exclut mutuellement avec --cidr.

    BYOIP (IPv4) Beta --cidr : La plage d' IPv4 s publiques pour cette plage d'adresses publiques, exprimée au format CIDR. Il doit s'agir d'un bloc non attribué au sein d'un CIDR personnalisé autorisé dans votre compte. S'exclut mutuellement avec --ipv4-address-count.

    --name
    Nom attribué à la plage d'adresses publiques. Les noms commençant par ibm- sont réservés aux ressources gérées par le fournisseur et ne sont pas autorisés.
    --vpc
    Le VPC auquel associer cette plage d'adresses publiques. Nécessite « --zone ».
    --zone
    La zone dans laquelle se trouve cette plage d'adresses publiques. Nécessite « --vpc ».
    --resource-group-id
    ID du groupe de ressources. S'exclut mutuellement avec --resource-group-name.
    --resource-group-name
    Nom du groupe de ressources. S'exclut mutuellement avec --resource-group-id.
    --output
    Format de sortie : seul le format JSON est pris en charge. Valeur admise : JSON.
    -q, --quiet
    Supprimer la sortie prolixe.

Exemples de commande

Créez une plage d'adresses publiques nommée public-address-range-1 avec un nombre d'adresses de 8 :

ibmcloud is public-address-range-create --name public-address-range-1 --ipv4-address-count 8

Créez une plage d'adresses publiques nommée public-address-range-2 comprenant 4 adresses et un groupe de ressources nommé Default:

ibmcloud is public-address-range-create --name public-address-range-2 --ipv4-address-count 4 --resource-group-name Default

Créer une plage d'adresses publiques nommée public-address-range-3 avec un nombre d'adresses de 8, liée au VPC cli-test-vpc dans la zone us-south-1 avec l'ID de groupe de ressources 72b27b5c-f4b0-48bb-b954-5becc7c1dcb3:

ibmcloud is public-address-range-create --name public-address-range-3 --ipv4-address-count 8 --vpc cli-test-vpc --zone us-south-1 --resource-group-id 72b27b5c-f4b0-48bb-b954-5becc7c1dcb3

BYOIP (IPv4) BetaCréer une plage d'adresses publiques à partir d'un CIDR personnalisé autorisé, associé à un VPC et à une zone :

ibmcloud is public-address-range-create --name public-address-range-3 --cidr 46.16.186.112/28 --vpc cli-test-vpc --zone us-south-2 --resource-group-name Default

Créer une plage d'adresses publiques non liée à partir d'un CIDR personnalisé autorisé :

ibmcloud is public-address-range-create --name public-address-range-4 --cidr 46.16.186.128/28 --resource-group-name Default

Créer des plages d'adresses publiques avec l'API

Avant de commencer, configurez votre environnement API.

Sélectionnez l'une des options suivantes :

  • Créer une plage d'adresses publiques à partir d'adresses IP gérées par l' IBM, associées à un VPC :

    curl -sX POST \
    "$vpc_api_endpoint/v1/public_address_ranges?version=$api_version&generation=2" \
    -H "Authorization: Bearer $iam_token" \
    -H "Content-Type: application/json" \
    -d '{
          "ipv4_address_count": 8,
          "name": "my-public-address-range",
          "target": {
             "vpc": {
                "id": "r006-4727d842-f94f-4a2d-824a-9bc9b02c523b"
             },
             "zone": {
                "name": "us-south-1"
             }
          }
       }'
    
  • Créer une plage d'adresses publiques non attribuées à partir des adresses IP gérées par l' IBM:

    curl -sX POST \
    "$vpc_api_endpoint/v1/public_address_ranges?version=$api_version&generation=2" \
    -H "Authorization: Bearer $iam_token" \
    -H "Content-Type: application/json" \
    -d '{
          "ipv4_address_count": 8,
          "name": "my-public-address-range"
       }'
    

BYOIP (IPv4) Beta

  • Créer une plage d'adresses publiques à partir d'un CIDR personnalisé autorisé (nécessite une action IAM is.public-address-range.authorized-cidr.operate sur le CIDR autorisé):

    curl -sX POST \
    "$vpc_api_endpoint/v1/public_address_ranges?version=$api_version&generation=2" \
    -H "Authorization: Bearer $iam_token" \
    -H "Content-Type: application/json" \
    -d '{
          "cidr": "192.168.3.192/28",
          "name": "my-par-from-cidr"
       }'
    

Si vous devez modifier la taille de la plage d'adresses ou du groupe de ressources, vous devez supprimer et recréer la plage d'adresses.

Etapes suivantes